@@ -4,14 +4,14 @@
 //
 // started November 2000
 // Peter Beerli Seattle 2000
-// $Id: bayes.h 175 2005-12-02 14:51:23Z beerli $
+// $Id: bayes.h 215 2006-01-03 00:03:51Z beerli $
 //
 #include "migration.h"
 extern boolean acceptBayes (MYREAL newval, MYREAL oldval);
 extern long bayes_update (world_fmt *world);
 extern void bayes_free(world_fmt *world);
 extern void bayes_fill(world_fmt *world, option_fmt *options);
-extern void bayes_init(bayes_fmt *bayes, long size);
+extern void bayes_init(bayes_fmt *bayes, world_fmt *world, option_fmt *options);
 extern void bayes_save(world_fmt *world);
 extern void bayes_stat(world_fmt *world);
 extern void bayes_init_histogram(world_fmt * world, option_fmt * options);
