@@ -25,7 +25,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: combroyden2.c 175 2005-12-02 14:51:23Z beerli $
+$Id: combroyden2.c 196 2005-12-18 15:43:16Z beerli $
  
 -------------------------------------------------------*/
 
@@ -201,8 +201,6 @@ estimateParameter (long rep, long G, world_fmt * world, option_fmt * options,
 
     boolean multilocus;
     nr_fmt *nr;
-    if (world->options->bayes_infer)
-        return -1; //when we run in Baysian mode we do not need to maximuze the likelihood
     nr = (nr_fmt *) mycalloc (1, sizeof (nr_fmt));
     if (kind == MULTILOCUS)
     {
