@@ -28,7 +28,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: joint-chains.c,v 1.24 2004/08/28 19:59:31 beerli Exp $
+$Id: joint-chains.c 175 2005-12-02 14:51:23Z beerli $
 */
 
 #include "migration.h"
@@ -81,7 +81,7 @@ void
 interpolate_like (nr_fmt * nr, long locus)
 {
     boolean alldone;
-    boolean diffdone;
+    boolean diffdone=FALSE;
     long j, z, r;
     long repdiff = nr->repstop - nr->repstart;
     MYREAL *newlike, *lparam;
