@@ -16,7 +16,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: lrt.c,v 1.36 2005/01/21 16:48:34 beerli Exp $
+$Id: lrt.c 175 2005-12-02 14:51:23Z beerli $
  
 -------------------------------------------------------*/
 /* \file lrt.c 
@@ -32,7 +32,7 @@ Calculates likelihood ratio tests
 #include "aic.h"
 #include "migrate_mpi.h"
 #ifndef LAGUERRE
-#include "derivatives2.h"
+//#include "derivatives2.h"
 #endif
 #include "sort.h"
 
@@ -163,6 +163,7 @@ test_loci_like (nr_fmt * nr, MYREAL *param0, MYREAL *param1, long df,
     MYREAL like1, like0;//, testval, chiprob, chiprob2;
  //   int length;
  //  
+    long numparam;
     long i, j, g = 0;
     long elem;
     //long zi;
@@ -170,6 +171,7 @@ test_loci_like (nr_fmt * nr, MYREAL *param0, MYREAL *param1, long df,
     // long pop;
     MYREAL normd = 0;
     long *which;
+    MYREAL **hess;
     MYREAL /**values,*/ *saveparam0;
     //MYREAL tparam;
 //    long spaces = 0;
@@ -180,13 +182,15 @@ test_loci_like (nr_fmt * nr, MYREAL *param0, MYREAL *param1, long df,
     MYREAL aicfull;
     long aicfullparamnum;
 //    char *message;
-    lparam0 = (MYREAL *) mycalloc (world->numpop2 + 1, sizeof (MYREAL));
-    lparam1 = (MYREAL *) mycalloc (world->numpop2 + 1, sizeof (MYREAL));
-    which = (long *) mycalloc (1, sizeof (long) * (world->numpop2 + 1));
+    numparam = world->numpop2 + 1;
+    doublevec2d(&hess,numparam, numparam);
+    lparam0 = (MYREAL *) mycalloc (numparam, sizeof (MYREAL));
+    lparam1 = (MYREAL *) mycalloc (numparam, sizeof (MYREAL));
+    which = (long *) mycalloc (1, sizeof (long) * numparam);
 //    message = (char *) mycalloc (20, sizeof (char));
     //  values = (MYREAL *) mycalloc (1, sizeof (MYREAL) * (world->numpop2 + 1));
-    saveparam0 = (MYREAL *) mymalloc (sizeof (MYREAL) * (world->numpop2 + 1));
-    memcpy (saveparam0, param0, sizeof (MYREAL) * (world->numpop2 + 1));
+    saveparam0 = (MYREAL *) mymalloc (sizeof (MYREAL) * numparam);
+    memcpy (saveparam0, param0, sizeof (MYREAL) * numparam);
     for (i = 0; i < loci; i++)
     {
         for (j = 0; j < world->repstop; j++)
@@ -195,7 +199,7 @@ test_loci_like (nr_fmt * nr, MYREAL *param0, MYREAL *param1, long df,
                 g = world->atl[j][i].T;
         }
     }
-    elem = world->options->gamma ? nr->numpop2 + 1 : nr->numpop2;
+    elem = world->options->gamma ? numparam : nr->numpop2;
     nr->skiploci = world->data->skiploci;
     helper.multilocus = world->loci == 1 ? FALSE : TRUE;
     if (maxnum > 0)
@@ -214,7 +218,7 @@ test_loci_like (nr_fmt * nr, MYREAL *param0, MYREAL *param1, long df,
             }
         }
         nr->profilenum = w;
-        maximize (&param0, world, nr, PROFILE, world->repkind);
+        maximize (&param0, world, nr, hess, PROFILE, world->repkind);
         like0 = nr->llike;
         normd = nr->normd;
         memcpy (param0, world->param0, sizeof (MYREAL) * nr->partsize);
@@ -270,6 +274,8 @@ test_loci_like (nr_fmt * nr, MYREAL *param0, MYREAL *param1, long df,
     free (lparam1);
     free (saveparam0);
     free (which);    
+    free(hess[0]);
+    free(hess);
 }
 
 void print_lrt_box(world_fmt *world, MYREAL *param0, MYREAL *param1, long zeros, long elem,
