@@ -26,7 +26,7 @@
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 178 2005-12-02 22:11:20Z beerli $
+/* $Id: main.c 241 2006-01-23 20:42:08Z beerli $
 * $Log: main.c,v $
 * Revision 1.114  2005/05/26 14:42:23  beerli
 * man changes most of which I don't remember , try to move to SVN and daily
@@ -308,7 +308,7 @@ main (int argc, char **argv)
   int argument;
     char type = 's';
     data_fmt *data;
-    int usize = HEATED_CHAIN_NUM;
+    int usize = 1;
     long Gmax = 0;
     long outfilepos = 0;
     option_fmt *options;
@@ -319,6 +319,7 @@ main (int argc, char **argv)
 #ifdef HAVE_NICE
     nice (10);			//nice value arbitrarily set to 10, 5 is still nice, 0 is standard
 #endif
+    puts(argv[0]);
 #ifdef PRETTY
 #ifdef WIN32
     set_haru_handler();
@@ -461,7 +462,7 @@ main (int argc, char **argv)
         {
             print_list (universe, options, data);
 #ifdef PRETTY
-            pdf_print_mcmctable(&page_height, page_width, EARTH, data, options);
+	    //	    pdf_print_mcmctable(&page_height, page_width, EARTH, data, options);
 #endif
             if (EARTH->options->gamma)
                 print_alpha_curve (EARTH, EARTH->atl, &Gmax);
@@ -545,7 +546,9 @@ main (int argc, char **argv)
 	free(seed);
 	free(newseed);
 	free(generator);
-        //free_universe(universe, usize);
+        free_universe(universe, usize, options);
+	destroy_data(data);
+	destroy_options(options);
         return 0;
 }				/* main end */
 
@@ -572,9 +575,12 @@ combine_loci_standard (char type, option_fmt * options, world_fmt * world,
 #ifdef LONGSUM
         change_longsum_times (world);	//multilocus
 #endif /*LONGSUM*/
-        (void) estimateParameter (options->replicatenum, *Gmax, world, options,
-                                  world->cov[world->loci], 0 /* chain */ ,
-                                  type, kind, world->repkind);
+	if(!options->bayes_infer)
+	  {
+	    (void) estimateParameter (options->replicatenum, *Gmax, world, options,
+				      world->cov[world->loci], 0 /* chain */ ,
+				      type, kind, world->repkind);
+	  }
     }
 }
 
@@ -608,11 +614,14 @@ combine_loci_mpi (char type, option_fmt * options, world_fmt * world,
 #endif	   /*LONGSUM*/
             // broadcast Gmax to all workers, the worker pendant is in mpi_gmax_worker
             MYMPIBCAST (Gmax, 1, MPI_LONG, MASTER, comm_world);
-            (void) estimateParameter (options->replicatenum, *Gmax, world,
-                                      options, world->cov[world->loci],
-                                      0 /* chain */ ,
-                                      type, kind, world->repkind);
-        }
+	    if (!options->bayes_infer)
+	      {
+		(void) estimateParameter (options->replicatenum, *Gmax, world,
+					  options, world->cov[world->loci],
+					  0 /* chain */ ,
+					  type, kind, world->repkind);
+	      }
+	}
         else
         {
             //            printf("%i> before gmax worker\n", myID);
@@ -647,7 +656,6 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
     long i;
     long maxreplicate;
     long treefilepos;
-    char *this_string;
 #ifdef PRETTY
     float left_margin;
 #endif /*PRETTY*/
@@ -670,7 +678,6 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
     twolongs = (long *) calloc (TWO, sizeof (long));
 #endif
     
-    this_string = (char *) mycalloc (1024, sizeof (char));
 #ifdef MPI
     
     if (myID == MASTER)
@@ -721,7 +728,7 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
         pdf_init();
         // add first page
         pdf_new_page(options->title);
-        pdf_print_title(options->title,  &page_height, &left_margin);
+        pdf_master_title(options->title,  &page_height, &left_margin);
         page_height -= 20; // option title should not straddle the line
         pdf_print_options(EARTH, options, data, &page_height, &left_margin);
         pdf_print_data_summary(EARTH, options, data,  &page_height, &left_margin);
@@ -759,9 +766,10 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
         // the first worker will always be here waiting 
         if (myID == FIRSTWORKER)
         {
-
             MYMPIRECV (twolongs, TWO, MPI_LONG, MASTER, 0, comm_world, &status);
-	    //fprintf(stdout,"%i> FIRSTWORKER kill off now non-loci-worker\n",myID);
+#ifdef MPI_DEBUG
+	    fprintf(stdout,"%i> FIRSTWORKER kill off now non-loci-worker\n",myID);
+#endif
 	    sent = mpi_send_stop_mcmc_replicateworker(numcpu,data->loci);
 	    //                mpi_send_stop_mcmc_worker (numcpu, data->loci, &comm_workers,
 	    //                             irequests, istatus, myID);
@@ -786,13 +794,13 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
         {
             for (i = 0; i < options->heated_chains; i++)
             {
-                // free_tree(universe[i]->root, universe[i]);
+	      //free_tree(universe[i]->root, universe[i]);
                 free_timevector (universe[i]->treetimes);
             }
         }
         else
         {
-            // free_tree(EARTH->root, EARTH);
+	  //free_tree(EARTH->root, EARTH);
             free_timevector (EARTH->treetimes);
         }
 #ifdef MPI
@@ -814,6 +822,7 @@ run_loci (world_fmt ** universe, int usize, option_fmt * options,
     {
         run_locus (universe, usize, options, data,
                    localheating_pool, maxreplicate, locus, treefilepos, Gmax);
+	free_datapart(data,options,locus);
     }
 }
 
@@ -1113,7 +1122,7 @@ analyze_olddata (world_fmt * world,
         pdf_init();
         // add first page
         pdf_new_page(options->title);
-        pdf_print_title(options->title,  &page_height, &left_margin);
+        pdf_master_title(options->title,  &page_height, &left_margin);
         page_height -= 20; // option title should not straddle the line
         pdf_print_options(world, options, data, &page_height, &left_margin);
         ////////////////////////////////////        
@@ -1132,10 +1141,13 @@ analyze_olddata (world_fmt * world,
 #ifdef LONGSUM
                 change_longsum_times (world);	//multi run replicates
 #endif	       /*LONGSUM*/
-                (void) estimateParameter (options->replicatenum, Gmax, world,
-                                          options, world->cov[locus], 1, 'l',
-                                          SINGLELOCUS, world->repkind);
-            }
+		if (!options->bayes_infer)
+		  {
+		    (void) estimateParameter (options->replicatenum, Gmax, world,
+					      options, world->cov[locus], 1, 'l',
+					      SINGLELOCUS, world->repkind);
+		  }
+	    }
         }
 #endif
         
@@ -1147,7 +1159,7 @@ analyze_olddata (world_fmt * world,
     }
 #endif
     return Gmax;
-}
+} /*analyze_olddata()*/
 
 /// generate profile likelihood tables
 void
@@ -1295,8 +1307,9 @@ condense_time (world_fmt * world, long *step, long *j, MYREAL * accepted,
 {
     
     if (world->in_last_chain && world->options->bayes_infer)
+      {
         bayes_save (world);
-
+      }
     world->rep = rep;
     if (*step == 0)
     {
@@ -1451,10 +1464,13 @@ run_locus (world_fmt ** universe, int usize, option_fmt * options,
         change_longsum_times (EARTH);
 #endif /*LONGSUM*/
         // over multiple replicates if present or single locus
-        (void) estimateParameter (options->replicatenum, *Gmax, EARTH,
-                                  options, EARTH->cov[locus],
-                                  options->lchains, /*type */ 'l',
-                                  SINGLELOCUS, EARTH->repkind);
+	if (!options->bayes_infer)
+	  {
+	    (void) estimateParameter (options->replicatenum, *Gmax, EARTH,
+				      options, EARTH->cov[locus],
+				      options->lchains, /*type */ 'l',
+				      SINGLELOCUS, EARTH->repkind);
+	  }
     }
     else
     {
@@ -1487,21 +1503,26 @@ run_locus (world_fmt ** universe, int usize, option_fmt * options,
 void
 run_one_update (world_fmt * world)
 {
-    long count = 0;
-    if (world->options->bayes_infer)
+  long count = 0;
+  long np = world->numpop2;
+  if (world->options->bayes_infer)
     {
-        world->bayesaccept = bayes_update (world);
-        if (world->bayesaccept == -1)	//either do tree updates or parameter updates
+      if(world->bayes->mu)
+	{
+	  np += 1; 
+	}
+      world->bayesaccept = bayes_update (world);
+      if (world->bayesaccept == -1)	//either do tree updates or parameter updates
         {
-            world->accept += (count = tree_update (world, world->G));
-            world->bayes->accept[world->numpop2] += count;	//permanent recorder for the tree acceptance, 
-                                                            // for some obscure reason the world->accept gets lost, most likely every cycle;
-            world->bayes->trials[world->numpop2] += 1;	// counter for trees tried 
+	  world->accept += (count = tree_update (world, world->G));
+	  world->bayes->accept[np] += count;	//permanent recorder for the tree acceptance, 
+	  // for some obscure reason the world->accept gets lost, most likely every cycle;
+	  world->bayes->trials[np] += 1;	// counter for trees tried 
         }
     }
-    else
+  else
     {
-        world->accept += tree_update (world, world->G);
+      world->accept += tree_update (world, world->G);
     }
 }
 
@@ -1663,9 +1684,12 @@ run_chains (world_fmt ** universe,
 #ifdef LONGSUM
         change_longsum_times (EARTH);
 #endif /*LONGSUM*/
-        (void) estimateParameter (rep, *Gmax, EARTH, options,
-                                  EARTH->cov[locus], chain, type, kind,
-                                  EARTH->repkind);
+	if (!options->bayes_infer)
+	  {
+	    (void) estimateParameter (rep, *Gmax, EARTH, options,
+				      EARTH->cov[locus], chain, type, kind,
+				      EARTH->repkind);
+	  }
         if (EARTH->options->heating)
             print_heating_progress (universe, EARTH->options, increment * steps);
         else
@@ -1756,9 +1780,12 @@ run_replicate (long locus,
 #ifdef LONGSUM
             change_longsum_times (EARTH);
 #endif	   /*LONGSUM*/
+	if (!options->bayes_infer)
+	  {
             (void) estimateParameter (replicate, *Gmax, EARTH, options,
                                       EARTH->cov[locus], chains, type,
                                       SINGLELOCUS, EARTH->repkind);
+	  }
         }
     }				//end runs
 }
