@@ -18,7 +18,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: mcmc1.c 175 2005-12-02 14:51:23Z beerli $
+$Id: mcmc1.c 223 2006-01-14 19:32:53Z beerli $
 -------------------------------------------------------*/
 /* \file mcmc1.c
 
@@ -45,7 +45,7 @@ Tree changer and acceptance rejection scheme
 #define MIGRATION_IN_TREE (boolean) 0
 #define NO_MIGR_NODES 0
 #define WITH_MIGR_NODES 1
-
+extern int myID;
 extern node * showtop();
 /* prototypes ------------------------------------------- */
 // metropolize over trees
@@ -187,8 +187,10 @@ tree_update (world_fmt * world, long g)
             {
                 if (!migrate (proposal, proposal->origin))
                 {
+		  // we end up here when the migration events exceed the upper limit
                     free_proposal (proposal);
                     free_timevector (timevector);
+		    //warning("Event was migration event but could not match a lineage to it\n");
                     return 0;
                 }
                 age = proposal->time;
@@ -221,6 +223,7 @@ tree_update (world_fmt * world, long g)
             free_timevector (timevector);
             return 0;
         }
+	//	fprintf(stderr,"%i> last time=%f, end time = %f (%c)\n", myID, age,(*timevector).tl[(*timevector).T-1].eventnode->tyme,(*timevector).tl[(*timevector).T-1].eventnode->type );
         pretendcoalesce1p (proposal);
 #ifdef UEP
 
@@ -234,42 +237,41 @@ tree_update (world_fmt * world, long g)
          || (world->options->uep && uepsuccess)) &&
 #endif
         (acceptlike (world, proposal, g, timevector)))
-    {
-        if (proposal->time > world->root->tyme)
-        {   /*saveguard */
+      {
+	if (proposal->time > world->root->tyme)
+	  {   /*saveguard */
             world->root->tyme += proposal->time;
-        }
+	  }
         coalesce1p (proposal);
 #ifdef UEP
-
+	
         world->likelihood[g] = treelikelihood (world);
         if (world->options->uep)
-        {
+	  {
             update_uep (world->root->next->back, world);
             check_uep_root (world->root->next->back, world);
             world->treelen = 0.0;
             calc_treelength (world->root->next->back, &world->treelen);
             world->ueplikelihood = ueplikelihood (world);
             world->likelihood[g] = /*world->ueplikelihood +*/ world->likelihood[g];
-        }
+	  }
 #else
         world->likelihood[g] = treelikelihood (world);
 #endif
         /* create a new timelist */
         construct_tymelist (world, &world->treetimes[0]);
         if (world->options->treeprint != NONE && (world->heat == 1.0))
-            print_tree (world, g, &treefilepos);
+	  print_tree (world, g, &treefilepos);
         world->migration_counts = 0;
         /* report the number of migration on the tree */
         count_migrations (world->root->next->back, &world->migration_counts);
         free_proposal (proposal);
         free_timevector (timevector);
         return 1;   /* new tree accepted */
-    }
+      }
     free_proposal (proposal);
     free_timevector (timevector);
-    return 0;   /* not accepted */
-
+    return 0;   /* not accepted */   
 }
 
 
@@ -582,7 +584,7 @@ add_locallineages (timelist_fmt * timevector, proposal_fmt * proposal)
         timevector->tl[0].lineages[proposal->osister->actualpop] += 1;
     else
         timevector->tl[timevector->T -
-                       1].lineages[timevector->tl[timevector->T - 2].from] += 1;
+                       1].lineages[timevector->tl[timevector->T-2].from] += 1;
     add_partlineages (numpop, &timevector);
 
 }
@@ -789,7 +791,7 @@ migration_from (long to, proposal_fmt * proposal)
     long ii = 0;
     MYREAL *r = proposal->world->migproblist[to];
     MYREAL rr = UNIF_RANDUM ();
-    while (rr > r[ii])
+    while (rr >  r[ii])
     {
         ii++;
     }
@@ -908,7 +910,9 @@ pre_population (proposal_fmt * proposal, vtlist * ltime, long gte,
     long pop1 = -99, pop2 = -98;
     //  long msta1=0, msto1=0;
     //  long msta2=0, msto2=0;
+    MYREAL  invrate = 1./proposal->world->options->mu_rates[proposal->world->locus];
     MYREAL age1, denom, rr, r0, r1, horizon, mm, mm2;
+    MYREAL denom_invrate;
     if (gte > 0)
         proposal->realtarget = ltime[gte - 1].eventnode;
     else
@@ -954,7 +958,8 @@ pre_population (proposal_fmt * proposal, vtlist * ltime, long gte,
         if (pop1 == pop2)
         {
             denom = mm + (2. / proposal->param0[pop1]);
-            proposal->time = age1 - LOG (UNIF_RANDUM ()) / denom;
+	    denom_invrate = denom * invrate;
+            proposal->time = age1 - LOG (UNIF_RANDUM ()) / denom_invrate;
             age1 = proposal->time;
             if (age1 < horizon)
             {
@@ -969,7 +974,7 @@ pre_population (proposal_fmt * proposal, vtlist * ltime, long gte,
         else
         {
             denom = mm;
-            proposal->time = age1 - LOG (UNIF_RANDUM ()) / denom;
+            proposal->time = age1 - LOG (UNIF_RANDUM ()) / (denom * invrate);
             age1 = proposal->time;
         }
         if (age1 < horizon)
@@ -997,12 +1002,17 @@ pre_population (proposal_fmt * proposal, vtlist * ltime, long gte,
         //{
         //mm += proposal->param0[i];
         //}
+
+      if(proposal->time > 1000000)
+	return 0;
+
         mm = proposal->mig0list[pop1];
         mm2 = proposal->mig0list[pop2];
         if (pop1 == pop2)
         {
             denom = 2. * mm + (2. / proposal->param0[pop1]);
-            proposal->time = age1 - LOG (UNIF_RANDUM ()) / denom;
+	    denom_invrate = denom * invrate;
+            proposal->time = age1 - LOG (UNIF_RANDUM ()) / denom_invrate;
             age1 = proposal->time;
             rr = UNIF_RANDUM ();
             r0 = ((2. / proposal->param0[pop1]) / denom);
@@ -1030,7 +1040,8 @@ pre_population (proposal_fmt * proposal, vtlist * ltime, long gte,
             //mm2 += proposal->param0[i];
             //}
             denom = mm + mm2;
-            proposal->time = age1 - LOG (UNIF_RANDUM ()) / denom;
+	    denom_invrate = denom * invrate;
+            proposal->time = age1 - LOG (UNIF_RANDUM ()) / denom_invrate;
             age1 = proposal->time;
             if (RANDUM () < (mm / denom))
             {
@@ -1211,19 +1222,31 @@ rmigrcount (proposal_fmt * proposal)
     return count;
 }
 
+
+///
+/// generates the time interval to the next event (migration or coalescence)
+/// and also decides what event happens.
+/// This funcion is modified by the rate of the mutation rate that can be
+/// estimated in a Bayesian context, and be fixed in a ML context
+/// this rate is only influencing the time and not the eventtype
+/// because the rate cancels out of the ratio that chooses the event.
 MYREAL
 eventtime (proposal_fmt * proposal, long pop, vtlist * tentry, char *event)
 {
 //    static boolean mig_force = TRUE;
-    MYREAL interval, lines, denom;
-    //MYREAL rate = proposal->world->options->mu_rates[proposal->world->locus];
-    MYREAL mm = proposal->mig0list[pop];
-    long design0 = proposal->design0list[pop];
-    lines = 2.0 * tentry->lineages[pop];
-    denom = mm + (lines / proposal->param0[pop]);
-    interval = (-(LOG (UNIF_RANDUM ())) / denom); // * rate;
-    if (interval < 0.0)
-        error("interval time is negative");
+    MYREAL  interval;
+    MYREAL  lines;
+    MYREAL  denom;
+    MYREAL  invrate = 1./proposal->world->options->mu_rates[proposal->world->locus];
+    MYREAL  mm         = proposal->mig0list[pop] /* / rate */;
+    //long    design0    = proposal->design0list[pop];
+ 
+    lines    = 2.0 * tentry->lineages[pop];
+    denom    = mm + (lines / (proposal->param0[pop]/* * rate*/));
+    interval = (-(LOG (UNIF_RANDUM ())) / (denom * invrate));
+    //[overcautious]
+    //if (interval < 0.0)
+    //    error("interval time is negative");
     if (lines > 0)
     {
         if ((UNIF_RANDUM ()) < (mm / denom))
@@ -1233,27 +1256,6 @@ eventtime (proposal_fmt * proposal, long pop, vtlist * tentry, char *event)
         }
         else
         {
-            /* if migration parameter x is 0
-               then we will insert a migration in population x
-               with probability so that 4Nm=0.1*theta
-             */
-            if ((mm <= SMALLEST_MIGRATION))
-            {
-                if (design0 < proposal->numpop - 1)
-                {
-                    if (RANDUM () < 0.1)
-                    {
-// WARNING might disturb flow in distributed runs and also quite useless 
-                        //                        if (mig_force)
-//                        {
-//                            warning ("Migration forced\nresults may be overestimating migration rates\nfor this chain\n");
-//                            mig_force = FALSE;
-//                        }
-                        *event = 'm';
-                        return interval;
-                    }
-                }
-            }
             *event = 'c';
             return interval;
         }
