@@ -17,7 +17,7 @@
   and is copyrighted. Of course, we do not guarantee that the software
   works and are not responsible for any damage you may cause or have.
 
-  $Id: menu.c 175 2005-12-02 14:51:23Z beerli $
+  $Id: menu.c 227 2006-01-19 04:31:25Z beerli $
 
   -------------------------------------------------------*/
 #include "migration.h"
@@ -60,7 +60,7 @@ void            get_plotmenu(option_fmt * options);
 boolean         menuStrategy_standard(option_fmt * options);
 boolean         menuStrategy_bayes(option_fmt * options);
 long            get_prior(char *input);
-void            set_prior(char *output, long prior);
+void            set_prior(char *output, int * prior);
 #define MI_INFILE 1
 #define MI_RAND 2
 #define MI_TITLE  3
@@ -165,8 +165,7 @@ void get_plotmenu(option_fmt * options) {
        options->plotscale == PLOTSCALELOG ? "Log10" : "Standard",
        options->plotintervals);
     printf("              Ranges: X-%5.5s: %f - %f\n",
-	   options->plotvar == PLOT4NM ? "xNm" : "M",
-	   options->plotrange[0], options->plotrange[1]);
+	   options->plotvar == PLOT4NM ? "xNm" : "M",	   options->plotrange[0], options->plotrange[1]);
     printf("              Ranges: Y-%5.5s: %f - %f\n",
 	   "Theta", options->plotrange[2],
 	   options->plotrange[3]);
@@ -850,8 +849,9 @@ menuInput(option_fmt * options) {
 
     printf("  %2i   Outputfile name is  %43.43s\n", MI_OUTFILE,
 	   options->outfilename);
+#ifdef PRETTY
     printf("                           %43.43s\n", options->pdfoutfilename);
-
+#endif
     if(!options->bayes_infer)
       {
 	if (options->plot) 
@@ -1652,8 +1652,244 @@ void            menuStrategy(option_fmt * options) {
   } while (done == FALSE);
 }
 
+//-------------------------------------------------------------------------------------
+// prior menu functions
+
+/// \brief Menu for multiplier proposal
+/// Menu for multiplier proposal
+void set_mult_prior(int paramgroupm, prior_fmt *prior)
+{
+  char input[LINESIZE];
+  long count = 0;
+  do {
+    printf("Specify the MINIMUM, MAXIMUM and maximal MULTIPLIER\n[Current setting: {%f %f %f}\n",
+	   prior->min, prior->max, prior->delta);
+    FGETS(input, LINESIZE, stdin);
+#ifdef USE_MYREAL_FLOAT
+    count = sscanf(input, "%f%f%f", &prior->min, &prior->max, &prior->delta);
+#else
+    count = sscanf(input, "%lf%lf%lf", &prior->min, &prior->max, &prior->delta);
+#endif
+  } while (count != 3 && count > 0);
+}
+
+/// \brief Menu for exponential proposal
+/// Menu for exponential proposal
+void set_exp_prior(int paramgroupm, prior_fmt *prior)
+{
+  char input[LINESIZE];
+  long count = 0;
+  do {
+    printf("Specify the MINIMUM, MEAN, MAXIMUM\n[Current setting: {%f %f %f}\n",
+	   prior->min, prior->mean, prior->max);
+    FGETS(input, LINESIZE, stdin);
+#ifdef USE_MYREAL_FLOAT
+    count = sscanf(input, "%f%f%f", &prior->min, &prior->mean, &prior->max);
+#else
+    count = sscanf(input, "%lf%lf%lf", &prior->min, &prior->mean, &prior->max);
+#endif
+  } while (count != 3 && count > 0);
+}
+
+/// \brief Menu for gamma proposal
+/// Menu for gamma proposal, mean = alpha * beta = 1 -> 
+void set_gamma_prior(int paramgroupm, prior_fmt *prior)
+{
+  char input[LINESIZE];
+  long count = 0;
+  do {
+    printf("Specify the MINIMUM, ALPHA, MAXIMUM\n[Current setting: {%f %f %f}\n",
+	   prior->min, prior->mean, prior->max);
+    FGETS(input, LINESIZE, stdin);
+#ifdef USE_MYREAL_FLOAT
+    count = sscanf(input, "%f%f%f", &prior->min, &prior->mean, &prior->max);
+#else
+    count = sscanf(input, "%lf%lf%lf", &prior->min, &prior->mean, &prior->max);
+#endif
+  } while (count != 3 && count > 0);
+}
+
+/// \brief Menu for exponential with window proposal
+/// Menu for exponential with window proposal
+void set_wexp_prior(int paramgroupm, prior_fmt *prior)
+{
+  char input[LINESIZE];
+  long count = 0;
+  do {
+    printf("Specify the MINIMUM, MEAN, MAXIMUM and DELTA\n[Current setting: {%f %f %f %f}\n",
+	   prior->min, prior->mean, prior->max, prior->delta);
+    FGETS(input, LINESIZE, stdin);
+#ifdef USE_MYREAL_FLOAT
+    count = sscanf(input, "%f%f%f%f", &prior->min, &prior->mean, &prior->max, &prior->delta);
+#else
+    count = sscanf(input, "%lf%lf%lf%lf", &prior->min, &prior->mean, &prior->max, &prior->delta);
+#endif
+  } while (count != 4 && count > 0);
+}
+
+/// \brief Menu for multiplier proposal
+/// Menu for multiplier proposal
+void set_uni_prior(int paramgroupm, prior_fmt *prior)
+{
+  char input[LINESIZE];
+  long count = 0;
+  do {
+    printf("Specify the MINIMUM, MAXIMUM\n[Current setting: {%f %f}\n",
+	   prior->min, prior->max);
+    FGETS(input, LINESIZE, stdin);
+#ifdef USE_MYREAL_FLOAT
+    count = sscanf(input, "%f%f", &prior->min, &prior->max);
+#else
+    count = sscanf(input, "%lf%lf", &prior->min, &prior->max);
+#endif
+  } while (count != 2 && count > 0);
+  prior->mean = (prior->max + prior->min) / 2.;
+  prior->delta = (prior->max - prior->min) / 10.;
+}
+
+/// \brief return "set" "-" depending on prior set
+/// returns a short string that shows whether this prior distribution is set
+char * is_prior(int priortype, int priorset)
+{
+  return priortype == priorset ? "Set" : "-";
+}
+
+/// \brief returns priortype sting
+/// returns a string that shows what prior distribution is set
+char * is_priortype(int priorset)
+{
+  switch(priorset)
+    {
+    case MULTPRIOR: return  "Multiplier" ; 
+    case EXPPRIOR: return "Exponential" ; 
+    case WEXPPRIOR: return "Exp window";
+    case GAMMAPRIOR: return "Gamma";
+    case UNIFORMPRIOR: return "Uniform";
+    default: return "-";
+    }
+}
+
+
+/// \brief Menu to set all prior distributions
+/// menu to set all prior distributions, returns TRUE when standard course of action
+/// FALSE when a problem occured.
+boolean set_prior_menu(int paramgroup, option_fmt *options)
+{
+  int tmp;
+  char            input[LINESIZE];
+  prior_fmt *prior;
+
+  switch(paramgroup)
+    {
+    case THETAPRIOR:
+      printf("Prior setting for all population sizes [Theta]:\n");
+      prior = options->bayespriortheta;
+      break;
+    case MIGPRIOR:
+      printf("Prior setting for all migration rates [%s]:\n",options->usem ? "M" : "Theta*M");
+      prior = options->bayespriorm;
+      break;
+    case RATEPRIOR:
+      printf("Prior setting for mutation rate modifier [r]:\n");
+      prior = options->bayespriorrate;
+      break;
+    default:
+      return FALSE;
+    }
+  do{
+    input[0] = '\0';
+    printf("\nSet the prior distribution and its parameters\n\n");
+    printf("  %i   Set Multiplication prior distribution?         %11s\n", MULTPRIOR, 
+	   is_prior(MULTPRIOR,options->bayesprior[paramgroup]));
+    printf("  %i   Set Exponential prior distribution?            %11s\n", EXPPRIOR, 
+	   is_prior(EXPPRIOR,options->bayesprior[paramgroup]));
+    printf("  %i   Set Exponential prior with window distribution?%11s\n", WEXPPRIOR,
+	   is_prior(WEXPPRIOR,options->bayesprior[paramgroup]));
+    printf("  %i   Set Gamma prior distribution?                  %11s\n", GAMMAPRIOR, 
+	   is_prior(GAMMAPRIOR,options->bayesprior[paramgroup]));
+    printf("  %i   Set Uniform prior distribution?                %11s\n\n", UNIFORMPRIOR,
+	   is_prior(UNIFORMPRIOR,options->bayesprior[paramgroup]));
+    printf("  (Type Y to go back to the main menu or the letter for an entry to change)\n");
+    FGETS(input, LINESIZE, stdin);
+    if(uppercase(input[0]) == 'Y')
+      return TRUE;
+    input[1] = '\0';
+    tmp = atoi(input);
+    switch (tmp) 
+      {
+      case UNIFORMPRIOR:
+	set_uni_prior(paramgroup, prior);
+	options->bayesprior[paramgroup] = UNIFORMPRIOR;	
+	break;
+      case EXPPRIOR:
+	set_exp_prior(paramgroup, prior);
+	options->bayesprior[paramgroup] = EXPPRIOR;	
+	break;
+      case WEXPPRIOR:
+	set_wexp_prior(paramgroup, prior);
+	options->bayesprior[paramgroup] = WEXPPRIOR;	
+	break;
+      case MULTPRIOR:
+	set_mult_prior(paramgroup, prior);
+	options->bayesprior[paramgroup] = MULTPRIOR;	
+	break;
+      case GAMMAPRIOR:
+	set_gamma_prior(paramgroup, prior);
+	options->bayesprior[paramgroup] = GAMMAPRIOR;	
+	break;
+      default:
+	set_uni_prior(paramgroup, prior);
+	options->bayesprior[paramgroup] = UNIFORMPRIOR;	
+	break;
+      }
+  }    while (uppercase(input[0]) != 'Y');
+  input[0]='\0';
+  return TRUE;
+}
+
+
 ///
-///reads menu choices and sets options accordingly
+/// sets prior distribution parameters
+void
+menuPrior(option_fmt * options) {
+  char            input[LINESIZE];
+  do 
+    {
+      input[0] = '\0';
+      printf ("  Prior distribution setting:\n");
+      printf("  1   Set Theta prior distribution?                 %11s\n", 
+	     is_priortype(options->bayesprior[THETAPRIOR]));
+      printf("  2   Set Migration prior distribution?             %11s\n",
+	     is_priortype(options->bayesprior[MIGPRIOR]));
+      if(options->bayesmurates)
+	{      
+	  printf("  3   Set mutation rate modifier prior distribution?%11s\n",
+	     is_priortype(options->bayesprior[RATEPRIOR]));
+	}
+      printf("\n  (Type Y to go back to the main menu or the letter for an entry to change)\n");
+      FGETS(input, LINESIZE, stdin);
+      switch (input[0]) 
+	{
+	case '1':
+	  set_prior_menu(THETAPRIOR, options);
+	  break;
+	case '2':
+	  set_prior_menu(MIGPRIOR, options);
+	  break;
+	case '3':
+	  if(options->bayesmurates)
+	    {      
+	      set_prior_menu(RATEPRIOR, options);
+	    }
+	  break;
+	default:
+	  break;
+	}
+    } while (uppercase(input[0]) != 'Y');;
+}
+
+///
+///reads bayes menu choices and sets options accordingly
 boolean menuStrategy_bayes(option_fmt * options) {
   char            input[LINESIZE];
   char           *priorstring;
@@ -1670,7 +1906,10 @@ boolean menuStrategy_bayes(option_fmt * options) {
   switch (atoi(input)) {
   case BAYESSTRATEGY:
     //strategy change
-    options->bayes_infer = !options->bayes_infer;
+
+    if (strchr(input,'0'))
+      options->bayes_infer = !options->bayes_infer;
+    input[0] = '\0';
     break;
   case BAYESOUT:
     printf(" Save posterior distribution (frequency histogram values)? [YES]\n");
@@ -1702,15 +1941,24 @@ boolean menuStrategy_bayes(option_fmt * options) {
     break;
   case BAYESBINNING:
     do {
-      printf("Specify the number of bins for THETA and %s!\nCurrent setting:  Bins      Interval width\n", options->usem ? "M" : "Theta*M");
-      printf("  Theta           %li           %f\n  %7.7s         %li           %f\n\n==> ",
-	     options->bayespriortheta->bins,
-	     (options->bayespriortheta->max - options->bayespriortheta->min) / (float) options->bayespriortheta->bins,
-	     options->usem ? "M" : "Theta*M", options->bayespriorm->bins,
+      printf("Specify the number of bins for THETA and %s!\n", options->usem ? "M" : "Theta*M");
+      printf("Current setting:  Bins      Interval width\n"); 
+      printf("  Theta           %li        %f\n", options->bayespriortheta->bins, 
+	     (options->bayespriortheta->max - options->bayespriortheta->min) / (float) options->bayespriortheta->bins);
+      printf("%7.7s            %li        %f\n", options->usem ? "M" : "Theta*M", options->bayespriorm->bins,
 	     (options->bayespriorm->max - options->bayespriorm->min) / (float) options->bayespriorm->bins);
+      if(options->bayesmurates)
+	printf("  Rate            %li        %f\n", options->bayespriorrate->bins, 
+	       (options->bayespriorrate->max - options->bayespriorrate->min) / (float) options->bayespriorrate->bins);
+      printf("\n==> ");
+
+	     
       FGETS(input, LINESIZE, stdin);
-      count = sscanf(input, "%li%li", &options->bayespriortheta->bins, &options->bayespriorm->bins);
-    } while (count != 2 && count > 0);
+      if(options->bayesmurates)
+	count = sscanf(input, "%li%li%li", &options->bayespriortheta->bins, &options->bayespriorm->bins, &options->bayespriorrate->bins);
+      else
+	count = sscanf(input, "%li%li", &options->bayespriortheta->bins, &options->bayespriorm->bins);
+    } while (count != (options->bayesmurates ? 3 : 2) && count > 0);
     break;
   case BAYESPRETTY:
     printf("Specify the method for plotting the posterior distribution!\n");
@@ -1744,126 +1992,16 @@ boolean menuStrategy_bayes(option_fmt * options) {
     break;
   case BAYESFREQ:
     do {
-      printf("What is the frequency of the parameter updates vs the tree updates?\n[suggestion for small problems: 0.5, actual value: %f]\n", options->updateratio);
+      printf("What is the frequency of the tree updates vs the parameter updates?\n");
+      printf("[A frequncy of 1.0 updates only trees, frequency of 0.0 updates only parameters]\n");
+      printf("[Suggestion for small problems: 0.5, actual value: %f]\n", options->updateratio);
       FGETS(input, LINESIZE, stdin);
-      options->updateratio = atof(input);
+      if (input[0] != '\0')  
+	  options->updateratio = atof(input);
     } while (options->updateratio > 1);
     break;
   case BAYESPRIOR:
-    set_prior(priorstring, options->bayesprior);
-    printf("Specify the prior distribution\nand its parameters[Choices:\n (M)multiplier proposal\n (E)XPONENTIAL proposal\n (W) EXPONENTIAL proposal using window size delta\n (U)NIFORM prior\n [current=%s]\n",
-           options->bayesprior==MULTPRIOR ? "multiplier" : 
-           options->bayesprior==EXPPRIOR ? "exponential" : 
-           options->bayesprior==WEXPPRIOR ? "exp window" : "uniform");
-    FGETS(input, LINESIZE, stdin);
-    options->bayesprior = get_prior(input);
-    switch (options->bayesprior) {
-    case MULTPRIOR:
-      count = 0;
-      do {
-	printf("Specify the MINIMUM, MAXIMUM and maximal MULTIPLIER for THETA\n[Current setting: {%f %f %f}\n",
-	       options->bayespriortheta->min, options->bayespriortheta->max, options->bayespriortheta->delta);
-	FGETS(input, LINESIZE, stdin);
-#ifdef USE_MYREAL_FLOAT
-	count = sscanf(input, "%f%f%f", &options->bayespriortheta->min, 
-		       &options->bayespriortheta->max, &options->bayespriortheta->delta);
-#else
-	count = sscanf(input, "%lf%lf%lf", &options->bayespriortheta->min, 
-		       &options->bayespriortheta->max, &options->bayespriortheta->delta);
-#endif
-      } while (count != 3 && count > 0);
-      count = 0;
-      do {
-	printf("Specify the MINIMUM, MAXIMUM, and maximal MULTIPLIER for the migration rate M\n[Current setting: {%f %f %f}\n",
-	       options->bayespriorm->min, options->bayespriorm->max, options->bayespriorm->delta);
-	FGETS(input, LINESIZE, stdin);
-#ifdef USE_MYREAL_FLOAT
-	count = sscanf(input, "%f%f%f", &options->bayespriorm->min, &options->bayespriorm->max, &options->bayespriorm->delta);
-#else
-	count = sscanf(input, "%lf%lf%lf", &options->bayespriorm->min, &options->bayespriorm->max, &options->bayespriorm->delta);
-#endif
-      } while (count != 3 && count > 0);
-      break;
-    case EXPPRIOR:
-      count = 0;
-      do {
-	printf("Specify the MINIMUM, MEAN, MAXIMUM for THETA\n[Current setting: {%f %f %f}\n",
-	       options->bayespriortheta->min, options->bayespriortheta->mean, options->bayespriortheta->max);
-	FGETS(input, LINESIZE, stdin);
-#ifdef USE_MYREAL_FLOAT
-	count = sscanf(input, "%f%f%f", &options->bayespriortheta->min, &options->bayespriortheta->mean, &options->bayespriortheta->max);
-#else
-	count = sscanf(input, "%lf%lf%lf", &options->bayespriortheta->min, &options->bayespriortheta->mean, &options->bayespriortheta->max);
-#endif
-      } while (count != 3 && count > 0);
-      count = 0;
-      do {
-	printf("Specify the MINIMUM, MEAN, MAXIMUM for migration rate M\n[Current setting: {%f %f %f}\n",
-	       options->bayespriorm->min, options->bayespriorm->mean, options->bayespriorm->max);
-	FGETS(input, LINESIZE, stdin);
-#ifdef USE_MYREAL_FLOAT
-	count = sscanf(input, "%f%f%f", &options->bayespriorm->min, &options->bayespriorm->mean, &options->bayespriorm->max);
-#else
-	count = sscanf(input, "%lf%lf%lf", &options->bayespriorm->min, &options->bayespriorm->mean, &options->bayespriorm->max);
-#endif
-      } while (count != 3 && count > 0);
-      break;
-    case WEXPPRIOR:
-      count = 0;
-      do {
-	printf("Specify the MINIMUM, MEAN, MAXIMUM and DELTA for THETA\n[Current setting: {%f %f %f %f}\n",
-	       options->bayespriortheta->min, options->bayespriortheta->mean, options->bayespriortheta->max, options->bayespriortheta->delta);
-	FGETS(input, LINESIZE, stdin);
-#ifdef USE_MYREAL_FLOAT
-	count = sscanf(input, "%f%f%f%f", &options->bayespriortheta->min, &options->bayespriortheta->mean,
-		       &options->bayespriortheta->max, &options->bayespriortheta->delta);
-#else
-	count = sscanf(input, "%lf%lf%lf%lf", &options->bayespriortheta->min, &options->bayespriortheta->mean,
-		       &options->bayespriortheta->max, &options->bayespriortheta->delta);
-#endif
-      } while (count != 4 && count > 0);
-      count = 0;
-      do {
-	printf("Specify the MINIMUM, MEAN, MAXIMUM and DELTA for migration rate M\n[Current setting: {%f %f %f %f}\n",
-	       options->bayespriorm->min, options->bayespriorm->mean, options->bayespriorm->max, options->bayespriorm->delta);
-	FGETS(input, LINESIZE, stdin);
-#ifdef USE_MYREAL_FLOAT
-	count = sscanf(input, "%f%f%f%f", &options->bayespriorm->min, &options->bayespriorm->mean,
-		       &options->bayespriorm->max, &options->bayespriorm->delta);
-#else
-	       count = sscanf(input, "%lf%lf%lf%lf", &options->bayespriorm->min, &options->bayespriorm->mean,
-			      &options->bayespriorm->max, &options->bayespriorm->delta);
-#endif
-      } while (count != 4 && count > 0);
-	     break;
-	   case UNIFORMPRIOR:
-	     count = 0;
-	     do {
-	       printf("Specify the MINIMUM and MAXIMUM for THETA\n[Current setting: {%f %f}\n",
-		      options->bayespriortheta->min, options->bayespriortheta->max);
-	       FGETS(input, LINESIZE, stdin);
-#ifdef USE_MYREAL_FLOAT
-	       count = sscanf(input, "%f%f", &options->bayespriortheta->min, &options->bayespriortheta->max);
-#else
-	       count = sscanf(input, "%lf%lf", &options->bayespriortheta->min, &options->bayespriortheta->max);
-#endif
-	     } while (count != 2 && count > 0);
-	     count = 0;
-	     do {
-	       printf("Specify the MINIMUM, MAXIMUM for migration rate M\n[Current setting: {%f %f}\n",
-		      options->bayespriorm->min, options->bayespriorm->max);
-	       FGETS(input, LINESIZE, stdin);
-#ifdef USE_MYREAL_FLOAT
-	       count = sscanf(input, "%f%f", &options->bayespriorm->min, &options->bayespriorm->max);
-#else
-	       count = sscanf(input, "%lf%lf", &options->bayespriorm->min, &options->bayespriorm->max);
-#endif
-	     } while (count != 2 && count > 0);
-	     options->bayespriortheta->mean = (options->bayespriortheta->max + options->bayespriortheta->min) / 2.;
-	     options->bayespriortheta->delta = (options->bayespriortheta->max + options->bayespriortheta->min) / options->bayespriortheta->bins;
-	     options->bayespriorm->mean = (options->bayespriorm->max + options->bayespriorm->min) / 2.;
-	     options->bayespriorm->delta = (options->bayespriorm->max + options->bayespriorm->min) / options->bayespriorm->bins;
-    }
+    menuPrior(options);
     break;
   case BAYESLCHAINS:
     do {
@@ -1877,7 +2015,7 @@ boolean menuStrategy_bayes(option_fmt * options) {
     break;
 	   case BAYESSKIP:
 	   do {
-	     printf("  How many trees to skip?\n");
+	     printf("  How many steps (tree changes, parameter changes) to skip?\n");
 	     FGETS(input, LINESIZE, stdin);
 	     options->lincrement = atoi(input);
 	     if (options->lincrement <= 0)
@@ -1887,7 +2025,7 @@ boolean menuStrategy_bayes(option_fmt * options) {
 	   break;
 	   case BAYESSAMPLES:
 	   do {
-	     printf("  How many trees to sample?\n");
+	     printf("  How many trees and parameter steps to sample?\n");
 	     FGETS(input, LINESIZE, stdin);
 	     options->lsteps = atoi(input);
 	     if (options->lsteps <= 0)
@@ -1897,7 +2035,7 @@ boolean menuStrategy_bayes(option_fmt * options) {
 	   break;
 	   case BAYESBURNIN:
 	   do {
-	     printf("  How many genealogies to discard?\n");
+	     printf("  How many steps to discard? (burn-in)\n");
 	     FGETS(input, LINESIZE, stdin);
 	     options->burn_in = atoi(input);
 	     if (options->burn_in <= 0)
@@ -1984,7 +2122,8 @@ boolean         menuStrategy_standard(option_fmt * options) {
   //make changes to options
   switch          (atoi(input)) {
   case MLSTRATEGY://strategy change
-    options->bayes_infer = !options->bayes_infer;
+    if (strchr(input,'0'))
+      options->bayes_infer = !options->bayes_infer;
     input[0] = '\0';
     break;
   case MLSHORTCHAINS:
@@ -2713,20 +2852,28 @@ long            get_prior(char *input) {
   }
 }
 
-void            set_prior(char *output, long prior) {
-  switch (prior) {
-  case MULTPRIOR:
-    sprintf(output, "Multiplier proposal");
-    break;
-  case EXPPRIOR:
-    sprintf(output, "Exponential proposal");
-    break;
-  case WEXPPRIOR:
-    sprintf(output, "Exponential with window proposal");
-    break;
-  case UNIFORMPRIOR:
-  default:
-    sprintf(output, "Uniform prior proposal");
-    break;
-  }
+///
+/// prints type of prior in the menu
+void            set_prior(char *output, int *prior)
+{
+  int i;
+  int l=0;
+  for(i=THETAPRIOR; i <= MIGPRIOR; i++)
+    {
+      switch (prior[i]) {
+      case MULTPRIOR:
+	l+=sprintf(output+l, " Mult.");
+	break;
+      case EXPPRIOR:
+	l+=sprintf(output+l, " Exp.");
+	break;
+      case WEXPPRIOR:
+	l+=sprintf(output+l, " WExp.");
+	break;
+      case UNIFORMPRIOR:
+      default:
+	l+=sprintf(output+l, " Unif.");
+	break;
+      }
+    }
 }
