@@ -10,7 +10,7 @@
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-  $Id: mig-histogram.c 175 2005-12-02 14:51:23Z beerli $
+  $Id: mig-histogram.c 224 2006-01-14 21:44:17Z beerli $
  
  */
 /*! \file mig-histogram.c
@@ -133,9 +133,11 @@ print_mighist_output (FILE * out, world_fmt * world, MYREAL ***migtable,
         {
                 if (migtable[loc][p1][2] == NOAVERAGE)
                 {
-                    FPRINTF (out, "%4li %4li    No migration event encountered\n",
-                             (long) migtable[loc][p1][0] + 1,
-                             (long) migtable[loc][p1][1] + 1);
+                    FPRINTF (out, "%4li %4li    No %s event encountered\n",
+			     (long) migtable[loc][p1][0] + 1,
+			     (long) migtable[loc][p1][1] + 1,
+			     (world->options->mighist_all && p1 < world->numpop) ?
+		      "coalescence" : "migration");
                 }
                 else
                 {
@@ -255,7 +257,7 @@ print_mighist (world_fmt * world)
         free (total);
         for (loc = 0; loc < loci1; loc++)
         {
-            for (i = 0; i < numpop2; ++i)
+            for (i = (world->options->mighist_all ? 0 : world->numpop); i < numpop2; ++i)
             {
                 free (migtable[loc][i]);
                 free (plotfield[loc][i].data[0]);
@@ -406,7 +408,7 @@ calc_migtable (MYREAL **migtable, histogram_fmt * histogram,
                           gencount[p1][p2]);
         }
     }
-    for (p1 = 0; p1 < world->numpop2; p1++)
+    for (p1 = (world->options->mighist_all ? 0 : world->numpop); p1 < world->numpop2; p1++)
     {
         total += (long) migtable[p1][5];
     }
@@ -544,6 +546,27 @@ setup_mighist (world_fmt * world, option_fmt * options)
             }
         }
     }
+    else
+      world->mighistloci = NULL;
+}
+
+void
+destroy_mighist (world_fmt * world)
+{
+    long locus, i;
+    if (world->options->mighist)
+    {
+      for (locus = 0; locus < world->loci; locus++)
+        {
+	  
+	  for (i = 0; i < world->mighistloci[locus].allocsize; i++)
+            {
+	      free(world->mighistloci[locus].mighist[i].migevents);
+            }
+	  free(world->mighistloci[locus].mighist);
+        }
+      free(world->mighistloci);
+    }
 }
 
 void
@@ -611,7 +634,7 @@ print_histogram_ascii (FILE * out, histogram_fmt ** histogram,
     {
         for (i = 0; i < nmigs; i++)
         {
-            if (migtable[loc][i][2] == NOAVERAGE)
+            if ((migtable[loc][i][2] == NOAVERAGE) || (plotfield[loc][i].y == NULL))
                 continue;
             //no event for this migration i->j
             memset (binvec, 0, sizeof (MYREAL) * (bins+1));
