@@ -19,7 +19,7 @@
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: options.h 175 2005-12-02 14:51:23Z beerli $
+$Id: options.h 220 2006-01-10 19:00:59Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -51,4 +51,9 @@ extern void read_options_master (option_fmt * options);
 extern void read_options_worker (char **buffer, option_fmt * options);
 extern long scan_connect (char *custm2, long start, long stop, char check);
 
+extern char * show_priormin(char *tmp, prior_fmt *prior, int priortype);
+extern char * show_priormean(char *tmp, prior_fmt *prior, int priortype);
+extern char * show_priormax(char *tmp, prior_fmt *prior, int priortype);
+extern char * show_priordelta(char *tmp, prior_fmt *prior, int priortype);
+extern char * show_priorbins(char *tmp, prior_fmt *prior, int priortype);
 #endif /*OPTIONS_INCLUDE */
