@@ -21,8 +21,8 @@
 extern int pdf_init();
 // print title on every new page
 extern int pdf_new_page(char *title);
-// print title with page number
-extern int pdf_print_title(char *title, float *orig_page_height, float *orig_left_margin);
+// print master title on first page 
+extern int pdf_master_title(char *title, float *orig_page_height, float *orig_left_margin);
 
 // OPTIONS
 // print options onto the first page
