@@ -16,7 +16,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: profile.c,v 1.75 2005/01/21 16:48:36 beerli Exp $
+$Id: profile.c 175 2005-12-02 14:51:23Z beerli $
  
 -------------------------------------------------------*/
 /*! \file profile.c
@@ -26,12 +26,7 @@ Calculation of profile likelihoods and printing of profile likelihood tables
 #include "migration.h"
 
 #include "world.h"
-#ifndef LAGUERRE
-#include "derivatives.h"
-#include "derivatives2.h"
-#else
 #include "laguerre.h"
-#endif
 #include "tools.h"
 #include "broyden.h"
 #include "combroyden.h"
@@ -107,9 +102,9 @@ long set_df (long which, char *custm2, long numpop, long numpop2);
 long set_profile_param (MYREAL *param, long which, long *allwhich,
                         MYREAL xval, MYREAL *xvals, world_fmt * world);
 void addinvar (MYREAL *param, long *fixed, long *allwhich, MYREAL *xvals,
-               long start, long len)
-;
-void sprint_nice_param (MYREAL parameter, MYREAL bottom, MYREAL top, boolean failed,
+               long start, long len);
+
+long sprint_nice_param (MYREAL parameter, MYREAL bottom, MYREAL top, boolean failed,
                         char *file);
 
 #ifdef PRIVATE
@@ -274,7 +269,7 @@ print_profile_table (char method, long which, char *var, MYREAL likes[],
                      MYREAL **param, world_fmt * world)
 {
     const MYREAL probabilities[] = SHOWGRID;
-
+    long failed = 0;
     char star;
     char methodstring[LINESIZE];
 
@@ -420,9 +415,12 @@ print_profile_table (char method, long which, char *var, MYREAL likes[],
                 else
                 {
                     if(world->percentile_failed[which][i])
+		      {
                         sprintf (fp, "**** %8.8s % 10.6g %s\n",
                                  likestr,
                                  param[i][which], paramstr);
+			failed += 1;
+		      }
                     else
                         sprintf (fp, "%4.3f %8.8s % 10.6g %s\n",
                                  probabilities[i], likestr,
@@ -438,10 +436,13 @@ print_profile_table (char method, long which, char *var, MYREAL likes[],
     bufsize += (long) strlen(fp);
     *buffer = (char *) myrealloc(*buffer, sizeof(char) * bufsize);
     strcat (*buffer, fp);
-    sprintf (fp, "If the percentile column is marked with **** then the convergence to the percentile value failed\nThe values are still _correct_ but not at the percentile of the profile parameter\n");
-    bufsize += (long) strlen(fp);
-    *buffer = (char *) myrealloc(*buffer, sizeof(char) * bufsize);
-    strcat (*buffer, fp);
+    if(failed>0)
+      {
+	sprintf (fp, "If the percentile column is marked with **** then the convergence to the percentile value failed\nThe values are still _correct_ but not at the percentile of the profile parameter\n");
+	bufsize += (long) strlen(fp);
+	*buffer = (char *) myrealloc(*buffer, sizeof(char) * bufsize);
+	strcat (*buffer, fp);
+      }
     free (paramstr);
     free (var2);
 }
@@ -476,6 +477,9 @@ warp (long ii)
 }
 
 
+///
+/// print profile tables for percentiles, returns the number
+/// of failed convergences to a specific percentile.
 void
 print_profile_percentile (world_fmt * world)
 {
@@ -486,11 +490,16 @@ print_profile_percentile (world_fmt * world)
     char fp[LINESIZE];
     char **buffer = &world->buffer;
     long bufsize = 1;
+    long failed=0;
+
+
     (*buffer)[0]='\0';
+    
     sprintf (fp, "\n\n");
     bufsize += (long) strlen(fp);
     *buffer = (char *) myrealloc(*buffer, sizeof(char) * bufsize);
     strcat (*buffer, fp);
+    
     sprint_line (fp, '=', 79, CONT);
     bufsize += (long) strlen(fp);
     *buffer = (char *) myrealloc(*buffer, sizeof(char) * bufsize);
@@ -528,7 +537,7 @@ print_profile_percentile (world_fmt * world)
             if (world->quantiles[i].param[j] < 0)
                 sprintf (fp, "      -       ");
             else
-                sprint_nice_param (world->quantiles[i].param[j], 0.000001,
+                failed += sprint_nice_param (world->quantiles[i].param[j], 0.000001,
                                    999.99999, world->percentile_failed[i][j], fp);
             bufsize += (long) strlen(fp);
             *buffer = (char *) myrealloc(*buffer, sizeof(char) * bufsize);
@@ -563,7 +572,7 @@ print_profile_percentile (world_fmt * world)
             if (world->quantiles[i].param[j] < 0)
                 sprintf (fp, "      -       ");
             else
-                sprint_nice_param (world->quantiles[i].param[j], 0.000001,
+                failed += sprint_nice_param (world->quantiles[i].param[j], 0.000001,
                                    999.99999, world->percentile_failed[i][j], fp);
             bufsize += (long) strlen(fp);
             *buffer = (char *) myrealloc(*buffer, sizeof(char) * bufsize);
@@ -583,29 +592,40 @@ print_profile_percentile (world_fmt * world)
     bufsize += (long) strlen(fp);
     *buffer = (char *) myrealloc(*buffer, sizeof(char) * bufsize);
     strcat (*buffer, fp);
-    sprintf (fp, "Values with a * are NOT at the percentiles!\nThe convergence to the percentile value FAILED.\n");
-    bufsize += (long) strlen(fp);
-    *buffer = (char *) myrealloc(*buffer, sizeof(char) * bufsize);
-    strcat (*buffer, fp);
+    if(failed > 0)
+    {
+        sprintf (fp, "Values with a * are NOT at the percentiles!\nThe convergence to the percentile value FAILED.\n");
+        bufsize += (long) strlen(fp);
+        *buffer = (char *) myrealloc(*buffer, sizeof(char) * bufsize);
+        strcat (*buffer, fp);
+    }
 }
 
-void
+long
 sprint_nice_param (MYREAL parameter, MYREAL bottom, MYREAL top, boolean failed, char *file)
 {
+  long failedcount=0;
     if (parameter > bottom && parameter < top)
     {
         if(failed)
+	  {
+            failedcount = 1;
             sprintf (file, " %11.6f* ", parameter);
+	  }
         else
             sprintf (file, " %11.6f  ", parameter);
     }
     else
     {
         if(failed)
-            sprintf (file, " %11.6g* ", parameter);
+	  {
+            failedcount = 1;
+	    sprintf (file, " %11.6g* ", parameter);
+	  }
         else
             sprintf (file, " %11.6g  ", parameter);
     }
+    return failedcount;
 }
 
 void
@@ -757,8 +777,8 @@ prognose_profile_end (time_t starttime, long numpop2, long nn)
     }
     else
         tally++;
-#endif
     free(nowstr);
+#endif
 }
 
 
@@ -873,11 +893,14 @@ profile_max_spline (char method, long which, MYREAL *likes, MYREAL **param,
     long len;
     MYREAL prob, normd, maxlike, testlike, minparam = 0, maxparam = 0;
     MYREAL *mlparam;
+    MYREAL **hess;
     MYREAL tmp, x, xx, xlow, xhigh, mid, low, high, value;
     long rep =
         world->options->replicate ? (world->loci > 1 ? 0 : world->repstop) : 0;
     spline_fmt *spline;
-
+    /* set the hessian for hte maximizer*/
+    doublevec2d(&hess, world->numpop2 + (long) world->options->gamma,
+		world->numpop2 + (long) world->options->gamma);
     /* set degree of freedom */
     df =
         (world->options->df > 0) ? world->options->df : set_df (which,
@@ -921,7 +944,7 @@ profile_max_spline (char method, long which, MYREAL *likes, MYREAL **param,
                                             value, nr->values, world);
         //do_profiles(nr->world, nr, likes, &normd, PROFILE,
         //          nr->world->rep, nr->world->repkind);
-        maximize (&param[i], world, nr, PROFILE, world->repkind);
+        maximize (&param[i], world, nr, hess, PROFILE, world->repkind);
         likes[i] = nr->llike;
         normd = nr->normd;
         memcpy (param[i], world->param0, sizeof (MYREAL) * nr->partsize);
@@ -1005,6 +1028,8 @@ profile_max_spline (char method, long which, MYREAL *likes, MYREAL **param,
                                   nn);
         }
         destroy_spline (spline);
+	free(hess[0]);
+	free(hess);
     }
 }
 
@@ -1358,7 +1383,9 @@ find_profilelike (MYREAL testlike, MYREAL prob, long whichprob, MYREAL minparam,
     long panic = 0;
     helper_fmt helper;
     MYREAL *ltestparam;
+    MYREAL **hess;
     long len = world->numpop2 +  (long) world->options->gamma;
+    doublevec2d(&hess,len,len);
 #ifdef LONGSUM
 
     len += world->numpop * 3;
@@ -1429,12 +1456,12 @@ find_profilelike (MYREAL testlike, MYREAL prob, long whichprob, MYREAL minparam,
         memcpy (*testparam, mlparam, sizeof (MYREAL) * len);
         nr->profilenum = set_profile_param (*testparam, which, nr->profiles,
                                             xlow, nr->values, world);
-        maximize (testparam, world, nr, PROFILE, world->repkind);
+        maximize (testparam, world, nr, hess, PROFILE, world->repkind);
         low = nr->llike;
         memcpy (*testparam, mlparam, sizeof (MYREAL) *len);
         nr->profilenum = set_profile_param (*testparam, which, nr->profiles,
                                             xhigh, nr->values, world);
-        maximize (testparam, world, nr, PROFILE, world->repkind);
+        maximize (testparam, world, nr, hess, PROFILE, world->repkind);
         high = nr->llike;
 
         // testlike = high - 0.5 * find_chi (1, prob);
@@ -1467,7 +1494,7 @@ find_profilelike (MYREAL testlike, MYREAL prob, long whichprob, MYREAL minparam,
             memcpy (*testparam, mlparam, sizeof (MYREAL) * nr->partsize);
             nr->profilenum = set_profile_param (*testparam, which, nr->profiles,
                                                 x, nr->values, world);
-            maximize (testparam, world, nr, PROFILE, world->repkind);
+            maximize (testparam, world, nr, hess, PROFILE, world->repkind);
             mid = *llike = nr->llike;
             *normd = nr->normd;
         }
@@ -1501,13 +1528,15 @@ find_profilelike (MYREAL testlike, MYREAL prob, long whichprob, MYREAL minparam,
             nr->profilenum =
                 set_profile_param (*testparam, which, nr->profiles, x, nr->values,
                                    world);
-            maximize (testparam, world, nr, PROFILE, world->repkind);
+            maximize (testparam, world, nr, hess, PROFILE, world->repkind);
             *llike = nr->llike;
             *normd = nr->normd;
             memcpy (*testparam, world->param0, sizeof (MYREAL) * nr->partsize);
         }
     }
     free (ltestparam);
+    free(hess[0]);
+    free(hess);
     return panic;
 }
 
