@@ -22,7 +22,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: random.c 175 2005-12-02 14:51:23Z beerli $
+$Id: random.c 204 2005-12-24 15:12:21Z beerli $
 -------------------------------------------------------*/
 /* \file random.c */
 #include "sighandler.h"
@@ -463,8 +463,8 @@ getseed (option_fmt * options)
     if (myID != MASTER)
     {
 #ifndef MERSENNE_TWISTER    
-        for (i = 1; i <= 1000; i++) /* clear the random number generator */
-            RANDUM ();
+      // for (i = 1; i <= 1000; i++) /* clear the random number generator */
+      //      RANDUM ();
 
         for (i = 0; i <= 2; i++)
             seed[i] = 0;
@@ -514,8 +514,8 @@ getseed (option_fmt * options)
 #else /* if we do not have SPRNG */
 
 #ifndef MERSENNE_TWISTER
-        for (i = 1; i <= 1000; i++) /* clear the random number generator */
-            RANDUM ();
+    //   for (i = 1; i <= 1000; i++) /* clear the random number generator */
+    //        RANDUM ();
     for (i = 0; i <= 2; i++)
         seed[i] = 0;
     i = 0;
