@@ -14,7 +14,7 @@ Copyright 2002 Peter Beerli and Joseph Felsenstein
         and is copyrighted. Of course, we do not guarantee that the software
         works and are not responsible for any damage you may cause or have.
  
-$Id: uep.c 175 2005-12-02 14:51:23Z beerli $
+$Id: uep.c 209 2005-12-26 23:13:22Z beerli $
 */
 /* \file uep.c 
 Unique event polymorphism manipulation
@@ -69,6 +69,47 @@ setup_uep (world_fmt * world, option_fmt * options)
     }
 }
 
+void
+destroy_uep (world_fmt * world)
+{
+  long locus;
+  if (world->options->uep)
+    {
+      free(world->uepanc[0]);
+      free(world->uepanc);
+      free(world->ueplike[0]);
+      free(world->ueplike);
+      for (locus = 0; locus < loci; locus++)
+	{
+	  for (i = 0; i < storesize; ++i)
+	    {
+	      for (j = 0; j < size; ++j)
+		{
+		  free(world->ueplikestore[locus][i][j]);
+		  free(world->ueptimestore[j].populations);
+		  free(world->ueptimestore[j].ueptime);
+		}
+	      free(world->ueplikestore[locus][i]);
+	      free(world->ueptimestore[locus][i]);
+	      free(world->ueprootstore[locus][i]);
+	    }
+	  free(world->ueplikestore[locus]);
+	  free(world->ueptimestore[locus]);
+	  free(world->ueprootstore[locus]);
+	}
+      free(world->ueplikestore);
+      free(world->ueptimestore);
+      free(world->ueprootstore);
+      for (j = 0; j < size; ++j)
+	{
+	  free(world->ueptime[j].populations);
+	  free(world->ueptime[j].ueptime);
+	}
+      free(world->ueptime);
+      free(world->oldrootuep);    
+    }
+}
+
 void
 pseudonu_twostate (proposal_fmt * proposal,
                    ueparray_fmt * xx1, MYREAL *lx1, MYREAL v1,
@@ -166,8 +207,9 @@ alloc_uepanc (long ***uepanc, long size, long numpop, long loci)
 {
     long locus;
     (*uepanc) = (long **) mycalloc (loci, sizeof (long *));
-    for (locus = 0; locus < loci; locus++)
-        (*uepanc)[locus] = (long *) mycalloc (2 * size * numpop, sizeof (long));
+    (*uepanc)[0] = (long *) mycalloc (loci * 2 * size * numpop, sizeof (long));
+    for (locus = 1; locus < loci; locus++)
+      (*uepanc)[locus] = (*uepanc)[0] + 2 * size * numpop;
 }
 
 void
