@@ -26,7 +26,7 @@ This software is distributed free of charge for non-commercial use
 and is copyrighted. Of course, we do not guarantee that the software
 works and are not responsible for any damage you may cause or have.
 
-$Id: world.h 175 2005-12-02 14:51:23Z beerli $
+$Id: world.h 209 2005-12-26 23:13:22Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -56,8 +56,7 @@ extern void create_plot (world_fmt * world, char ***plane,
 extern void print_simresults (world_fmt * world);
 extern void print_list (world_fmt ** universe, option_fmt * options,
                             data_fmt * data);
-extern void cleanup_world (world_fmt * world, long locus);
-extern void free_universe (world_fmt ** worlds, long numworlds);
+extern void free_universe (world_fmt ** worlds, long numworlds, option_fmt *options);
 extern void test_locus_like (nr_fmt * nr, MYREAL *param0, MYREAL *param1,
                                  long df, long locus, world_fmt * world,
                                  long *maxwhich, long maxnum, boolean withhead,
@@ -86,5 +85,4 @@ extern void print_mighist (world_fmt * world);
 extern void print_gelmanr (MYREAL average, MYREAL biggest);
 extern void prognose_time (char *nowstr, world_fmt * world,
                            long options_increment, long steps, char *spacer, boolean tobuffer);
-
 #endif /*WORLD_INCLUDE */
